@@ -149,9 +149,11 @@ class KubeModel(ABC):
 
         weight_key = f'{job_id}:optimizer:{func_id}' 
         pickled_val  = pickle.dumps(self.optimizer.state_dict())
+
+        self.logger.debug(f"Optimizer value {pickled_val}")
+
         self._redis_client.set(weight_key, pickled_val)
 
-        self.logger.debug('Saved optimizer to the database')
 
     def _load_optimizer_redis(self):
         """
@@ -185,7 +187,7 @@ class KubeModel(ABC):
         func_id = self.args._func_id
         epoch = self.args.epoch
 
-        self.logger.debug("Saving optimizer to the database")
+        self.logger.debug("Saving test case to the database")
 
         weight_key = f'{job_id}:test:{func_id}' 
         value = f'{job_id}:test:{func_id}/{epoch}' 
@@ -200,11 +202,11 @@ class KubeModel(ABC):
         job_id = self.args._job_id
         func_id = self.args._func_id
 
-        self.logger.debug("Load optimizer from the database")
+        self.logger.debug("Load test case from the database")
 
         weight_key = f'{job_id}:test:{func_id}' 
         pickled_val = self._redis_client.get(weight_key)
-        self.logger.debug("loading value: ", pickled_val)
+        self.logger.debug(f"loading value:  {pickled_val}")
 
 
     def _get_logger(self):
